(this.webpackJsonpstreamlit_component_template=this.webpackJsonpstreamlit_component_template||[]).push([[0],{5:function(e,t,n){e.exports=n(6)},6:function(e,t,n){"use strict";n.r(t);var o=n(2),A=n(4),a="<img src='data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAQAAAC1HAwCAAAAC0lEQVR42mNkYAAAAAYAAjCB0C8AAAAASUVORK5CYII='>";o.a.events.addEventListener(o.a.RENDER_EVENT,(function(e){var t=e.detail,n=document.body.lastElementChild;n&&document.body.removeChild(n);var i=document.body.appendChild(document.createElement("div"));new A.a((function(e,t){o.a.setFrameHeight()})).observe(document.body),i.innerHTML=a+t.args.html_content+a;for(var m=document.getElementsByTagName("a"),c=function(e){m[e].onclick=function(){o.a.setComponentValue(m[e].id)}},d=0;d<m.length;d++)c(d)})),o.a.setComponentReady()}},[[5,1,2]]]);
//# sourceMappingURL=main.3a09928b.chunk.js.map